
domDocument *  XML_SimpleParseDocument ( char *xml, int ignoreWhiteSpaces,
                                         int keepCDATA, int forest,
                                         char *baseURI, Tcl_Obj *extResolver,
                                         domLength *pos, char **errStr );
